<?php

declare(strict_types=1);

namespace Drupal\sync_clients\SyncClientPause;

use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Defines Sync Client Pause object.
 */
interface SyncClientPauseInterface {

  /**
   * The pause cause 'forced'.
   *
   * To be used when pause state forced by the error level raising mechanism or
   * other (fatal) errors indicating that any future requests will also fail.
   * When active, the pause state should only be manually undone.
   *
   * @var string
   */
  public const PAUSE_CAUSE_FORCED = 'forced';

  /**
   * The pause cause 'maintenance'.
   *
   * Is used when Drupal's Maintenance Mode is active.
   * Should only be used by isPaused().
   *
   * @var string
   */
  public const PAUSE_CAUSE_MAINTENANCE = 'maintenance';

  /**
   * The pause cause 'manual'.
   *
   * To be used when pause state is manually set.
   * When active, the pause state should only be manually undone.
   *
   * @var string
   */
  public const PAUSE_CAUSE_MANUAL = 'manual';

  /**
   * Get the cause.
   *
   * @return string
   *   The pause cause.
   */
  public function getCause(): string;

  /**
   * Message with pause cause and reason.
   *
   * For status messages or inclusion in mails.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The message.
   */
  public function getPauseMessage(): TranslatableMarkup;

  /**
   * Check if the pause was forced.
   *
   * @return bool
   *   TRUE if the cause equals PAUSE_CAUSE_FORCED.
   */
  public function isForced(): bool;

  /**
   * Check if the pause is due to maintenance.
   *
   * @return bool
   *   TRUE if the cause equals PAUSE_CAUSE_MAINTENANCE.
   */
  public function isMaintenance(): bool;

  /**
   * Check if the pause was manually set.
   *
   * @return bool
   *   TRUE if the cause equals PAUSE_CAUSE_MANUAL.
   */
  public function isManual(): bool;

}
